$(document).ready(function()
{
    let elapsedTime         = consumed ? consumed : 0;
    let lastInteractionTime = Date.now();
    let hasOperation        = true;

    updateTimer(elapsedTime);

    /* 监听鼠标移动事件。
     * Listen for mouse movement events.
     *
     * @access public
     * @return void
     */
    document.addEventListener("mousemove", function () {
      lastInteractionTime = Date.now();
    });

    /* 监听键盘键入事件。
     * Listen for keydown events.
     *
     * @access public
     * @return void
     */
    document.addEventListener("keydown", function () {
      lastInteractionTime = Date.now();
    });

    /* 检查最后一次触发事件的时间。
     * Check the time of the last triggered event.
     *
     * @access public
     * @return void
     */
    function checkLastInteraction() {
      const currentTime = Date.now();
      const timeSinceLastInteraction = currentTime - lastInteractionTime;

      /* 30秒没有触发事件，则不能计算时间 */
      /* If there is no triggering event within 30 seconds, time cannot be calculated */
      hasOperation = timeSinceLastInteraction <= 30000;
    }

    /* 每秒检查最后一次触发事件的时间 */
    /* Check the time of the last triggered event per second */
    registerTimer(checkLastInteraction, 1000, 'interval');

    /* 每隔30秒更新一次消耗时间 */
    /* Updating every 30 seconds takes time */
    registerTimer(updataConsumedTime, 30000, 'interval');

    /* 更新消耗时间
     * Update consumption time
     *
     * @access public
     * @return void
     */
    function updataConsumedTime() {
        if(!hasOperation) return;
        const consumedData = Number(elapsedTime) + 30;
        $.ajax({
            url: updateConsumedUrl,
            method: 'POST',
            dataType: 'json',
            data: {
                consumed: consumedData,
            },
            success: function(res)
            {
                if(res.result == 'fail')
                {
                    alert(res.message.name)
                    return false;
                }
                else
                {
                    elapsedTime = consumedData;
                    updateTimer(elapsedTime);
                }
            },
        })
    }

    $('.think-step textarea.form-control').parent('div').removeAttr('title');

    /* 初始化侧边栏的隐藏与显示状态。*/
    /* Initialize the hide and show status of the sidebar.*/
    var hiddenSidebar = localStorage.getItem('hiddenSidebar');
    if(hiddenSidebar == null)
    {
        localStorage.setItem('hiddenSidebar', true);
        $('.think-node-menu').closest(".sidebar").sidebar("toggle");
    }
});

/**
 * 提交答题结果。
 * Submit the answer results.
 *
 * @param  string type
 * @access public
 * @return void
 */
window.onSubmitResult = function(type)
{
    $("[name=status]").val(type);
    const url  = $('.design-content form').attr('action');
    const form = new FormData($('.design-content form')[0]);
    $.ajaxSubmit(
    {
        url,
        data: form,
        onFail: (error) => {
            if($('.think-step .form-batch-table').length)
            {
                $('.form-batch-table .form-control').removeClass('has-error');
                $('.form-batch-table .ajax-form-tip').remove();
            }

            if(error?.message) showValidateMessage(error.message);
        }
    });
}
