<?php
/**
 * The resultbygraph view file of thinkrun module of ZenTaoPMS.
 * @copyright   Copyright 2009-2023 禅道软件（青岛）有限公司(ZenTao Software (Qingdao) Co., Ltd. www.zentao.net)
 * @license     ZPL(https://zpl.pub/page/zplv12.html) or AGPL(https://www.gnu.org/licenses/agpl-3.0.en.html)
 * @author      Yu Zhang <zhangyu@easycorp.ltd>
 * @package     thinkrun
 * @link        https://www.zentao.net
 */
namespace zin;

$bodyTrs = array();
$stepIndex = 1;

function renderTableInput($step, $stepOptions, $stepAnswer, $stepIndex)
{
    global $lang;
    $fieldIndex    = 0;
    $result        = (array) $stepAnswer->result;
    $customFields  = !empty($stepAnswer->customFields) ? get_object_vars($stepAnswer->customFields) : array();
    $filedsCount   = count(array_merge($stepOptions->fields, $customFields));
    $tableInputHrs = [];

    foreach($stepOptions->fields as $item)
    {
        $tableInputHrs[] = h::tr
        (
            $fieldIndex == 0 ? h::td($stepIndex, set::rowspan($filedsCount)) : null,
            $fieldIndex == 0 ? h::td($lang->thinkrun->tableResult->tableQuestionType['tableInput'], set::rowspan($filedsCount)) : null,
            h::td($step->title . '-' . $item),
            h::td(isset($result[$fieldIndex]) ? span($result[$fieldIndex]) : span($lang->thinkrun->tableResult->notFilledIn))
        );
        $fieldIndex ++;
    }
    foreach($customFields as $item)
    {
        $tableInputHrs[] = h::tr
        (
            h::td($step->title . '-' . $item),
            h::td(!empty($result[$fieldIndex]) ? span($result[$fieldIndex]) : span($lang->thinkrun->tableResult->notFilledIn))
        );
        $fieldIndex ++;
    }
    return $tableInputHrs;
}

function renderMulticolumn($stepFields, $result)
{
    global $lang;
    $multicolumnHead    = array();
    $multicolumnBodyTrs = array();
    $maxResultCount     = count((array) reset($result));

    foreach($stepFields as $fieldIndex => $filed)
    {
        $multicolumnHead[] = h::th($filed);
    }
    for($i = 1; $i <= $maxResultCount; $i++)
    {
        $row = array();
        $emptyCount = 0;
        foreach($stepFields as $fieldIndex => $filed)
        {
            if(!empty($result['col' . ($fieldIndex + 1)]))
            {
                $columnResult = $result['col' . ($fieldIndex + 1)]->$i;
                $row[] = h::td(!empty($columnResult) ? $columnResult : span(setClass('hidden'), $lang->thinkrun->tableResult->notFilledIn));
                if(empty($columnResult)) $emptyCount ++;
            }
        }
        $multicolumnBodyTrs[] = $emptyCount >= count($stepFields) ? null : h::tr($row);
    }
    return h::table
    (
        setClass('w-full'),
        h::thead($multicolumnHead),
        h::tbody($multicolumnBodyTrs)
    );
}

function fnBuildCheckboxTable($blockIndex, $stepLink, $stepOptions, $stepAnswer)
{
    global $lang;
    $result = (array) $stepAnswer->result;
    $answer = array();
    if(!empty($stepLink->unSelectedBlock) && $stepLink->unSelectedBlock == $blockIndex)
    {
        $unSelectedItems = array_diff($stepOptions->fields, $result);
        foreach($unSelectedItems as $unSelectedItem)
        {
            $answer[] = span(setClass('mr-3'), $unSelectedItem);
        }
        if(isset($stepOptions->enableOther) && $stepOptions->enableOther === 'on' && empty($stepAnswer->other)) $answer[] = $lang->thinkrun->other;
    }
    else
    {
        foreach($result as $resultItem)
        {
            $answer[] = span(setClass('mr-3'), $resultItem === 'other' ? $stepAnswer->other : $resultItem);
        }
    }
    return $answer;
}

$fnBuildBlockTable = function(int $blockIndex, string $block, array $steps)
{
    global $lang;
    $fnBlockTable = array();
    $letter = range('a', 'z');
    if(empty($steps))
    {
        $fnBlockTable[] = h::tr
        (
            h::td($block . ' (' . $letter[$blockIndex -1] . $lang->thinkrun->tableResult->block . ')'),
            h::td(setClass('text-center'), set::colspan(3), $lang->thinkrun->tableResult->noneContent)
        );
        return $fnBlockTable;
    }

    foreach($steps as $stepBlockIndex => $step)
    {
        $stepLink     = json_decode($step->link);
        $stepOptions  = $step->options;
        $questionType = $stepOptions->questionType;
        $stepAnswer   = $step->answer;
        $result       = (array) $stepAnswer->result;
        $answer       = array();

        if($stepOptions->questionType === 'multicolumn')
        {
            $answer = renderMulticolumn($stepOptions->fields, $result);
        }
        elseif($questionType === 'radio' || $questionType === 'checkbox')
        {
            $answer = fnBuildCheckboxTable($blockIndex, $stepLink, $stepOptions, $stepAnswer);
        }
        $fnBlockTable[] = h::tr
        (
            $stepBlockIndex == '0' ? h::td($block . ' (' . $letter[$blockIndex -1] . $lang->thinkrun->tableResult->block . ')', set::rowspan(count($steps))) : null,
            h::td($lang->thinkrun->tableResult->tableQuestionType[$questionType]),
            h::td($step->title),
            h::td(setClass($questionType == 'multicolumn' ? 'multicolumn-table' : ''), $answer)
        );
    }
    return $fnBlockTable;
};

if(in_array($wizard->model, $this->config->thinkwizard->venn))
{
    foreach($wizard->blocks as $index => $block)
    {
        $steps     = $this->thinkrunZen->buildBlockTableSteps($questionSteps, $index);
        $bodyTrs[] = $fnBuildBlockTable($index + 1, $block, $steps);
    }
}
else
{
    foreach($questionSteps as $step)
    {
        $stepOptions   = $step->options;
        $questionType  = $stepOptions->questionType;
        $stepAnswer    = $step->answer;
        $result        = (array) $stepAnswer->result;
        $answer        = array();
        $tableInputHrs = array();

        if($questionType === 'tableInput')
        {
            $tableInputHrs[] = renderTableInput($step, $stepOptions, $stepAnswer, $stepIndex);
        }
        elseif($questionType == 'multicolumn')
        {
            $answer[] = renderMulticolumn($stepOptions->fields, $result);
        }
        else
        {
            foreach($result as $item)
            {
                $answer[] = span(setClass('mr-3'), $item === 'other' ? $stepAnswer->other : $item);
            }
            if(empty($answer)) $answer[] = span($lang->thinkrun->tableResult->notFilledIn);
        }
        $bodyTrs[] = $questionType !== 'tableInput' ? h::tr
        (
            h::td($stepIndex),
            h::td($lang->thinkrun->tableResult->tableQuestionType[$questionType]),
            h::td($step->title),
            h::td(setClass($questionType == 'multicolumn' ? 'multicolumn-table' : ''), $answer)
        ) : $tableInputHrs;
        $stepIndex ++;
    }
}

panel
(
    setStyle(array('overflow' => 'unset')),
    set::bodyClass('p-4'),
    setID('runResult'),
    div
    (
        setClass('leading-normal w-full text-left text-xl wizard-introduction'),
        $wizard->introduction
    ),
    div(
        setClass('result-table overflow-auto mt-3'),
        in_array($wizard->model, $this->config->thinkwizard->venn) ? h::table
        (
            setID('thinkrun-result-table'),
            setClass('w-full border-primary border-opacity-50 border text-base font-normal text-gray-700'),
            h::thead
            (
                setClass('sticky'),
                setStyle(array('top' => '-1px')),
                h::tr(
                    setClass('bg-primary-100 h-9'),
                    h::th(setStyle('text-align', 'center'), $lang->thinkrun->tableResult->resultsGraphical)
                )
            ),
            h::tbody
            (
                h::tr
                (
                    h::td(img(setClass('w-1/4 m-auto p-2'), set::src('data/thinmory/background/block3c.svg')))
                )
            )
        ) : null,
        h::table
        (
            setID('thinkrun-result-table'),
            setClass('w-full border-primary border-opacity-50 border text-base font-normal text-gray-700'),
            h::thead
            (
                setClass('sticky'),
                setStyle(array('top' => '-1px')),
                h::tr(
                    setClass('bg-primary-100 h-9'),
                    h::th(in_array($wizard->model, $this->config->thinkwizard->venn) ? $lang->thinkrun->tableResult->blockName : $lang->thinkrun->tableResult->number, setClass('w-20 min-number')),
                    h::th($lang->thinkrun->tableResult->questionType, setClass('w-28 min-type')),
                    h::th($lang->thinkrun->tableResult->questionName, setClass('w-1/3 min-name')),
                    h::th(in_array($wizard->model, $this->config->thinkwizard->venn) ? $lang->thinkrun->tableResult->exhibitContent : $lang->thinkrun->tableResult->answer)
                )
            ),
            h::tbody($bodyTrs)
        )
    ),
    !empty($wizard->suggestion) ? div
    (
        setClass('w-full leading-5 text-base mt-4 py-4.5 text-left wizard-suggestion'),
        section
        (
            setClass('break-words'),
            set::content( htmlspecialchars_decode($wizard->suggestion)),
            set::useHtml(true)
        )
    ) : null,
    $run->conclusion ? div(
        setClass('w-full leading-5 text-base mt-4 py-4.5 text-left run-conclusion'),
        $run->conclusion
    ) : null
);
