<?php
/**
 * The result view file of thinkwizard module of ZenTaoPMS.
 * @copyright   Copyright 2009-2024 禅道软件（青岛）有限公司(ZenTao Software (Qingdao) Co., Ltd. www.zentao.net)
 * @license     ZPL(https://zpl.pub/page/zplv12.html) or AGPL(https://www.gnu.org/licenses/agpl-3.0.en.html)
 * @author      Zemei Wang <liugang@easycorp.ltd>
 * @package     thinkwizard
 * @link        https://www.zentao.net
 */
namespace zin;

jsVar('marketID', $marketID);
jsVar('wizardID', $wizard->id);
jsVar('steps', $steps);
jsVar('unAssociatedLang', $lang->thinkwizard->unAssociated);
jsVar('stepID', $stepID);

detailHeader
(
    to::prefix
    (
        backBtn(set::icon('back'), set::type('secondary'), set::url(inlink('admin', "marketID=$marketID")), $lang->goback)
    ),
    to::title
    (
        entityLabel
        (
            setClass('text-xl font-black'),
            set::level(1),
            set::text($wizard->name)
        )
    ),
    to::suffix
    (
        cell
        (
            setClass('flex items-center'),
            common::hasPriv('thinkwizard', 'publish') ? btn
            (
                setClass('text-primary'),
                setStyle(array('padding-left' => '6px', 'padding-right' => '6px')),
                set::type('ghost'),
                set::icon('publish'),
                $lang->thinkwizard->abbr->publish,
                on::click('publishForResult')
            ) : null,
            div(setClass('divider my-2 mr-3 ml-1.5')),
            btnGroup
            (
                set::size('md'),
                setStyle(array('--btn-radius' => '13px')),
                set::items(array(
                    array('text' => $lang->thinkstep->viewSwitcher[0], 'class' => 'btn text-sm text-gray',    'onclick' => 'window.switchViewOfResult()'),
                    array('text' => $lang->thinkstep->viewSwitcher[1], 'class' => 'btn text-sm text-primary', 'style' => array('background' => 'var(--color-primary-50)', '--tw-ring-color' => 'var(--color-primary-300)'))
                ))
            )
        )
    )
);

$fnBuildBlocks = function() use ($wizard, $steps)
{
    global $lang;

    $blocks = array();
    foreach($wizard->blocks as $key => $block)
    {
        $block = !isset($steps[$block]) ? 0 : $block;
        $blocks[] = div
        (
            setClass('w-full flex items-center gap-1.5 mb-2 item-block'),
            div
            (
                setClass('h-8 text-gray flex items-center justify-center'),
                setStyle(array('min-width' => '60px', 'max-width' => '60px', 'background' => 'rgba(var(--color-gray-200-rgb), .6)')),
                $lang->thinkwizard->block . $lang->thinkwizard->blockList[$key]
            ),
            picker
            (
                set(array(
                    'class'       => "flex-1 blocks picker-$key",
                    'name'        => 'blocks[]',
                    'placeholder' => $lang->thinkwizard->placeholder->blocks,
                    'items'       => $steps,
                    'value'       => $block,
                    'menu'        => array('getItem' => jsRaw("(item) => window.convertBlockItem($key, item)"))
                )),
                on::change("changeBlock(target, $key)")
            )
        );
    }
    return $blocks;
};

$isVenn        = in_array($wizard->model, $config->thinkwizard->venn);
$canlink       = common::hasPriv('thinkstep', 'link');
$canCancelLink = common::hasPriv('thinkstep', 'cancelLink');

$fnBuildTbody = function(array $steps, int $blockID) use ($wizard, $canlink, $canCancelLink)
{
    global $lang;

    $blockID += 1;
    $tbody = array();
    foreach($steps as $step)
    {
        $options      = json_decode($step->options, true);
        $link         = json_decode($step->link, true);
        $questionType = $options['questionType'];
        $content      = '';

        if($link['showMethod'] == '2')
        {
            $content = $lang->thinkwizard->resultArea->fullQuestion;
        }
        elseif($link['showMethod'] == '1')
        {
            $colKey = $link['column'][0];
            if(isset($options['fields'][$colKey - 1])) $content = sprintf($lang->thinkwizard->resultArea->columnOrder, $colKey) . ':' . $options['fields'][$colKey - 1];
        }
        else
        {
            $content = !empty($link['selectedBlock']) && $link['selectedBlock'] == $blockID ? $lang->thinkstep->label->selected : $lang->thinkstep->label->nonSelected;
        }

        $items = array();
        if($canlink)       $items[] = array('icon' => 'design', 'class' => "ghost text-primary", 'hint' => $lang->thinkwizard->resultArea->link,   'data-toggle' => 'modal', 'data-size' => 'sm', 'url' => createLink('thinkstep', 'link', array('marketID' => $wizard->market, 'stepID' => $step->id, 'wizardID' => $wizard->id, 'from' => '', 'hiddenUnlink' => true)));
        if($canCancelLink) $items[] = array('icon' => 'unlink', 'class' => "ghost text-primary", 'hint' => $lang->thinkwizard->resultArea->unlink, 'data-confirm' => array('message' => $lang->thinkstep->tips->cancelLink, 'icon' => 'icon-exclamation-sign', 'iconClass' => 'warning-pale rounded-full icon-2x'), 'url' => createLink('thinkstep', 'cancelLink', array('stepID' => $step->id, 'type' => 'block', 'blockID' => $blockID, 'columnID' => !empty($link['column']) && !empty($link['column'][0]) ? $link['column'][0] : null)));

        $tbody[] = h::tr
        (
            h::td(setStyle(array('min-width' => '200px', 'max-width' => '200px')), setClass('w-1/3'), btn
            (
                setClass('ghost text-primary px-0 text-ellipsis block flex items-center justify-start'),
                set::url(createLink('thinkstep', 'view', array('marketID' => $wizard->market, 'wizardID' => $wizard->id, 'stepID' => $step->id, 'from' => 'detail'))),
                setData('toggle', 'modal'),
                setData('dismiss', 'modal'),
                setData('size', 'sm'),
                set::hint($step->title),
                span(setClass('text-ellipsis'), $step->title)
            )),
            h::td(setClass('w-1/6'), span($lang->thinkstep->$questionType)),
            h::td(setClass('w-1/6'), span($content)),
            empty($items) ? null : h::td(setClass('w-1/6'), setStyle(array('padding-left' => '0.7rem', 'padding-right' => '0.7rem')), btnGroup(set::items($items)))
        );
    }
    return $tbody;
};

$fnBuildBlockTable = function(int $index, string $block, array $steps) use ($fnBuildTbody, $canlink, $canCancelLink)
{
    global $lang;

    return div
    (
        setClass('p-3.5 bg-gray-100'),
        p
        (
            setClass('h-5 leading-5 text-sm block-title mb-2 text-ellipsis'),
            set::title($block . $lang->thinkwizard->block),
            span(setClass("block-title-$index"), $block),
            $lang->thinkwizard->block
        ),
        empty($steps) ? div(setClass('text-gray-400 block-empty-tip'), $lang->thinkwizard->resultArea->unAssociated) : h::table
        (
            set::key("questions-$index"),
            setClass('table bordered bg-gray-50'),
            h::tbody
            (
                h::tr
                (
                    h::td(setClass('text-gray-600 w-1/3'), setStyle(array('min-width' => '200px', 'max-width' => '200px')), $lang->thinkwizard->resultArea->questionName),
                    h::td(setClass('text-gray-600 w-1/6'), $lang->thinkwizard->resultArea->questionType),
                    h::td(setClass('text-gray-600 w-1/6'), $lang->thinkwizard->resultArea->content),
                    ($canlink || $canCancelLink) ? h::td(setClass('text-gray-600 w-1/6'), $lang->actions) : null
                ),
                $fnBuildTbody($steps, $index)
            )
        )
    );
};

$fnBuildVennBlocks = function() use ($wizard, $fnBuildBlockTable)
{
    $blocks = array();
    foreach($wizard->blocks as $index => $block)
    {
        $steps = $this->thinkwizard->getRelatedStepsByBlock($wizard->id, $index + 1);
        $blocks[] = $fnBuildBlockTable($index, $block, $steps);
    }

    return div(setClass('col gap-3 mt-1'), $blocks);
};

$previewBlocks = array();
if(!$isVenn)
{
    foreach($wizard->blocks as $block)
    {
        $item = new stdClass();
        $item->text = !isset($steps[$block]) ? '' : $steps[$block];
        $item->id   = !isset($steps[$block]) ? 0 : $block;
        $previewBlocks[] = $item;
    }
}
else
{
    $previewBlocks = $wizard->blocks;
}

formPanel
(
    setClass('h-full pt-1 col think-result items-stretch'),
    set::layout('grid'),
    div
    (
        setClass('w-full flex items-stretch gap-4'),
        setStyle(array('min-height' => 'calc(100vh - 165px)')),
        panel
        (
            setClass('w-1/2 flex-1'),
            set::bodyClass('px-0 pt-0'),
            set::headingClass('h-12 border-b border-gray-100'),
            set::titleClass('font-medium text-gray-950'),
            set::title($lang->thinkwizard->resultArea->config),
            formGroup(set(array(
                'style'       => array('padding' => 'var(--form-grid-gap-y-half) calc(8 * var(--space))'),
                'label'       => $lang->thinkwizard->introduction,
                'placeholder' => $lang->thinkwizard->placeholder->introduction,
                'name'        => 'introduction',
                'value'       => $wizard->introduction
            ))),
            formGroup
            (
                set(array(
                    'class'     => 'hidden',
                    'style'     => array('padding' => 'var(--form-grid-gap-y-half) calc(8 * var(--space))'),
                    'label'     => $lang->thinkwizard->background,
                    'control'   => 'picker',
                    'required'  => true,
                    'name'      => 'background',
                    'items'     => $backgroundPairs,
                    'value'     => $wizard->background
                )),
                on::change('showBlocks')
            ),
            $isVenn ? formGroup(setStyle(array('padding' => 'var(--form-grid-gap-y-half) calc(8 * var(--space))')), set::label($lang->thinkwizard->blocks), set::labelHint($lang->thinkwizard->hint->vennBlocks), setClass('relative'), $canlink ? btn
            (
                setClass('ghost absolute top-1.5 text-primary'),
                setStyle(array('right' => 'calc(8 * var(--space))')),
                set::icon('plus'),
                set::text($lang->thinkwizard->resultArea->associate),
                set::disabled(empty($relatedSteps)),
                setData('toggle', 'modal'),
                setData('size', 'sm'),
                set::url(createLink('thinkstep', 'link', array('marketID' => $wizard->market, 'stepID' => 0, 'wizardID' => $wizard->id))),
                empty($relatedSteps) ? set::hint($lang->thinkwizard->hint->associate) : null
            ) : null, $fnBuildVennBlocks) : formGroup(setStyle(array('padding' => 'var(--form-grid-gap-y-half) calc(8 * var(--space))')), set::label($lang->thinkwizard->blocks), set::labelHint($lang->thinkwizard->hint->blocks), $fnBuildBlocks),
            formGroup
            (
                setStyle(array('padding' => 'var(--form-grid-gap-y-half) calc(8 * var(--space))')),
                set::label($lang->thinkwizard->suggestion),
                editor
                (
                    set::placeholder($lang->thinkwizard->placeholder->suggestion),
                    set::name('suggestion'),
                    html(htmlspecialchars_decode($wizard->suggestion))
                )
            )
        ),
        panel
        (
            setClass('w-1/2 flex-1'),
            set::bodyClass('px-0 pt-0'),
            set::headingClass('h-12 border-b border-gray-100'),
            set::titleClass('font-medium text-gray-950'),
            set::title($lang->thinkwizard->resultArea->preview),
            thinkResult(set::mode('preview'), set::wizard($wizard), set::blocks($previewBlocks))
        )
    ),
    set::actions(array(array('text' => $lang->save, 'class' => 'primary', 'btnType' => 'submit'))),
    set::actionsClass('z-10 fixed bottom-0 flex justify-center bg-white border-t border-gray-100 w-full')
);
